<template>
    <div class="content-body">
        <screenHeader :currentKey="currentKey">
            <div class="content-container">
                <div class="inner-contianer">
                    <div class="side-nav" :class="!showNav ? 'hidden' : ''" v-if="comp === 'mapTarget'">
                        <div class="side-nav-title">指标列表</div>

                        <div @click="changeNav(mapTargetAll)
                            " :class="[
                                'side-nav-sort',
                                'side-nav-all',
                                {
                                    active:
                                        indexName == '改革报表分档结果'
                                }
                            ]">
                            改革报表分档结果
                        </div>
                        <div class="side-nav-sort">本期晾晒指标</div>
                        <div @click="changeNav(item)" :class="[
                            'side-nav-item',
                            { active: indexName == item.name },
                            { disable: item.number == 0 },
                        ]" v-for="item in lsIndex" :key="item.key">
                            {{ item.name }}
                        </div>
                        <div class="side-nav-sort" v-if="noIndex.length">
                            本期未晾晒指标
                        </div>
                        <div @click="changeNav(item)" :class="[
                            'side-nav-item',
                            { active: indexName == item.name },
                            { disable: item.number == 0 },
                        ]" v-for="item in noIndex" :key="item.key">
                            {{ item.name }}
                        </div>
                    </div>
                    <div class="main-content" :class="comp === 'mapTarget' && showNav ? 'short' : ''
                        ">
                        <img v-if="comp === 'mapTarget' || comp === 'mapTarget_All'" :class="showNav ? '' : 'hidden'"
                            class="side-nav-img" src="@/assets/img/bigScreen/sz_btn.png" @click="handleSideNav" />
                        <div class="sub-title-container">
                            <div class="sub-title-content">
                                {{ title || '' }}
                            </div>
                            <el-button v-if="plExport" style="background: transparent" class="view-btn" plain
                                @click="cxzyExport" icon="el-icon-download"
                                :loading="cxzyExportLoading">批量导出</el-button>
                            <el-button style="background: transparent" v-if="comp === 'mapTarget'" class="view-btn"
                                @click="previewExport" plain icon="el-icon-view">图片导出</el-button>
                            <el-button style="background: transparent" v-if="reportBtn" class="view-btn"
                                @click="openSubDialog('satisfactionReport')" plain>满意度报告</el-button>
                            <download-excel v-if="comp === 'mapTarget'" :data="allTable" :fetch="createExportData"
                                :fields="json_fields" :name="exportName">
                                <el-button class="view-btn" plain icon="el-icon-download">导出Excel</el-button>
                            </download-excel>
                            <el-button v-if="comp === 'projectStatementDetail' || comp === 'projectBatchZB' || comp === 'projectBatchMH'" style="background: transparent"
                                class="view-btn" plain @click.once="monthExportExcel"
                                icon="el-icon-download">导出Excel</el-button>
                            <el-button v-if="(year > 2024 || (year === 24 && quarter !== 1))&&indexName !== '改革报表分档结果'&&comp === 'mapTarget'" style="background: transparent;margin-left: 8px;" class="view-btn" icon="el-icon-download"
                               @click="frontDownload" plain>指标详情</el-button>

                            <img class="sub-back" src="@/assets/img/bigScreen/subBack.png" alt="sub-back"
                                @click="handleBack" />
                        </div>
                        <div class="sub-content-container">
                            <component v-bind:is="currentTabComponent" :options="options"
                                @searchDateChange="searchDateChange"></component>
                        </div>
                    </div>
                </div>
            </div>
        </screenHeader>
        <previewExport ref="previewExport" v-if="comp === 'mapTarget'"></previewExport>
        <EasyDialog v-model="showEasy" :top="dialogOption.top" :width="dialogOption.width"
            :title="dialogOption.dialogTitle">
            <component v-bind:is="dilogComponent" :options="tableOptions"></component>
        </EasyDialog>
    </div>
</template>

<script>
import subPageComponents from '@/views/BigScreen/js/sub_page_components.js'
import subPage from '@/views/BigScreen/js/sub_page_config.js'
import apiList from '@/api/bigScreen/districView.js'
import screenHeader from '@/views/BigScreen/components/screenHeader.vue'
import previewExport from '@/views/BigScreen/components/subComponents/previewExport.vue'
import EasyDialog from '@/views/BigScreen/components/easy-dialog/index.vue'
import dialogConfig from '@/views/BigScreen/js/DistrictReformDialogConfig.js'
import req from '@/request.js'
import { getLsOrNotIndex } from './js/getIndex'
import { debounce } from 'lodash'
const portal = window.context.portal
export default {
    components: {
        screenHeader,
        previewExport,
        ...subPageComponents,
        EasyDialog,
    },
    data() {
        return {
            currentKey: '',
            currentTabComponent: '',
            options: null,
            compData: null,
            title: '',
            showNav: true,
            viewBtn: false,
            reportBtn: false,
            allTable: [],
            json_fields: {},
            navData: [],
            quarter: null,
            year: null,
            plExport: false,
            cxzyExportLoading: false,
            exportName: '',
            lsIndex: [],
            noIndex: [],
            dialogOption: {
                dialogTitle: '',
                width: '50%',
            },
            showEasy: false,
            tableOptions: null,
            dilogComponent: '',
            comp: '',
            indexName: '',
            mapTargetAll: {},
            scoreKey: '',
            excelName: ''
        }
    },
    watch: {
        $route: 'debouncePoliyComp',
    },
    beforeDestroy() {
        this.$bus.$off('changeDateComp')
    },
    created() {
        this.currentKey = localStorage.getItem('currentKey')
    },
    mounted() {
        let searchDate = sessionStorage.getItem('searchDate')
        let { comp, name } = this.$route.query
        this.comp = comp
        if (searchDate) {
            searchDate = JSON.parse(searchDate)
            this.year = searchDate.year
            this.quarter = searchDate.quarter
        } else {
            this.checkQuarter()
        }
        this.$bus.$on('changeDateComp', (searchDate) => {
            this.quarter = searchDate.quarter
            this.year = searchDate.year
            this.debouncePoliyComp()
        })
        if (name === '满意度') {
            this.reportBtn = true
        }
        if (comp === 'innovationPromotion') {
            this.plExport = true
        }
        this.debouncePoliyComp()
        this.$bus.$on('exportExcel', (res) => {
            this.allTable = res
        })
    },
    beforeRouteUpdate(to, from, next) {
        let { comp, name } = to.query
        if (name === '满意度') {
            this.reportBtn = true
        } else {
            this.reportBtn = false
        }
        if (comp === 'innovationPromotion') {
            this.plExport = true
        } else {
            this.plExport = false
        }
        next()
    },
    methods: {
        frontDownload() {
          console.log('this.excelName',this.excelName)
            var a = document.createElement('a') // 创建一个<a></a>标签
            a.href = `./files/excel/${this.excelName}`
            a.download = this.excelName // 设置下载文件文件名
            a.style.display = 'none' // 隐藏a标签
            document.body.appendChild(a) // 将a标签追加到文档对象中
            a.click() // 模拟点击了a标签，会触发a标签的href的读取，浏览器就会自动下载了
            a.remove() // 一次性的，用完就删除a标签
        },
        monthExportExcel() {
            this.$bus.$emit('monthExportExcel', this.comp)
        },
        openSubDialog(type, dataOptions) {
            this.dilogComponent = dialogConfig.dialogOption[type].componentName
                ? dialogConfig.dialogOption[type].componentName
                : type // 动态组件名称
            if (dataOptions) {
                this.tableOptions = {
                    ...dialogConfig.dialogOption[type].dataOptions,
                    ...dataOptions,
                }
            } else {
                this.tableOptions = dialogConfig.dialogOption[type].dataOptions //table的查询参数
            }
            this.dialogOption = dialogConfig.dialogOption[type].option //弹窗配置参数
            this.showEasy = true
        },
        // 设置表格数据
        setExcelData(quarterIndexData) {
            let { name } = this.$route.query
            console.log(quarterIndexData.find(item => item.name === name));
            let indexObj = quarterIndexData.find(item => item.name === name)
            let {title,tableColumn,value} = indexObj
            this.scoreKey = value
            this.exportName = title
            let json_fields = {}
            tableColumn.forEach(item => {
                json_fields[item.label] = item.prop
            })
            json_fields['分档']= indexObj.grade
            this.json_fields = json_fields
        },
        // 设置导出的数据顺序
        createExportData() {
            return this.allTable.sort((a, b) => b[this.scoreKey] - a[this.scoreKey])
        },
        checkQuarter() {
            this.year = new Date().getFullYear()
            let month = new Date().getMonth() + 1
            if (month <= 3) {
                this.quarter = 1
            } else if (month <= 6) {
                this.quarter = 2
            } else if (month <= 9) {
                this.quarter = 3
            } else if (month <= 12) {
                this.quarter = 4
            }
        },
        previewExport() {
            this.$refs.previewExport.open(this.lsIndex, this.mapTargetAll)
        },
        cxzyExport() {
            this.cxzyExportLoading = true
            req.downloadPostCopy(
                portal +
                `/county/largeScreen/v1/indexRankExport?quarter=${this.quarter}&year=${this.year}`
            ).then((res) => {
                this.cxzyExportLoading = false
            })
        },
        searchDateChange() {
            this.currentKey = 'MajorProjectsView'
            this.$forceUpdate()
        },
        handleBack() {
            let { comp } = this.$route.query
            if (comp.indexOf('mapTarget') == -1) {
                this.$router.back()
            } else {
                this.$router.push({
                    path: '/DistrictReformView',
                    name: 'DistrictReformView',
                })
            }
        },
        debouncePoliyComp: debounce(function () {
            this.poliyComp()
        }, 500),
        poliyComp() {
            let { comp, name, title } = this.$route.query
            this.indexName = name
            let { year, quarter } = JSON.parse(
                sessionStorage.getItem('searchDate')
            )
            this.options = subPage.configOption[comp].options
            if (comp === 'mapTarget') {
                apiList.getTarget({ quarter, year }).then(res => {
                    if (res.value) {
                        let { totalGear, quarterIndexData } = getLsOrNotIndex({ quarter, year })
                        this.mapTargetAll = totalGear
                        quarterIndexData.forEach(item => {
                            item.number = res.value[item.value] || 0
                            item.unitValue = res.value[item.unit] || '分'
                        })
                        let activeItem = quarterIndexData.find(item => item.name === name)
                        let sendData = activeItem && activeItem.number !== 0 ? activeItem : totalGear
                        if (sendData.excelName) {
                            this.excelName = sendData.excelName
                        } else {
                            this.excelName = ''
                        }
                        this.$bus.$emit('loadElement', sendData)
                        this.title = activeItem && activeItem.number !== 0 ? activeItem.title : totalGear.title
                        if (!activeItem || activeItem.number === 0) {
                            this.changeNav(totalGear)
                        }
                        // 季度晾晒指标
                        this.lsIndex = quarterIndexData.filter(item => item.dryingOrNot) || []
                        // 季度非晾晒指标
                        this.noIndex = quarterIndexData.filter(item => !item.dryingOrNot) || []
                        this.setExcelData([totalGear,...quarterIndexData])
                    }
                })
            } else {
                if (title) {
                    this.title = title
                } else {
                    this.title = this.options.title
                }
            }
            this.currentTabComponent = subPage.configOption[comp].options.comp
        },
        changeNav(nav) {
            if (nav.number || nav.name === "改革报表分档结果") {
                this.$bus.$emit('rightLoading')
                this.$router.push({
                    path: '/DetailComponent',
                    name: 'DetailComponent',
                    query: {
                        comp: 'mapTarget',
                        name: nav.name
                    },
                })
            }
        },
        handleSideNav() {
            this.showNav = !this.showNav
        },
    },
}
</script>

<style lang="scss" scoped>
@import '@/assets/css/big-screen.scss';

::v-deep .easy-dialog {
    height: 85vh;

    .content-diy {
        // height: 595PX;
        height: 77vh;
    }
}

.view-btn {
    height: 35px;
    line-height: 35px;
    padding: 0 10px;
    background: transparent;

    font-size: 14PX;
    font-weight: 600;
    border: 1px #2761ff solid;
    color: #fff;

    &:hover {
        background-color: transparent;
        color: #fff;
    }

    &:last-child {
        background-color: transparent;
        margin-left: 10px;
    }

    &:active {
        background-color: transparent;
        color: #fff;
    }
}

.content-container {
    width: 100%;
    height: 100%;
    box-sizing: border-box;
    padding: 20px 34px 5px 34px;
}

.inner-contianer {
    display: flex;
    width: 100%;
    height: 100%;
    box-sizing: border-box;
}

.side-nav {
    width: 168PX;
    height: 100%;
    background-color: #082753;
    box-sizing: border-box;
    transition: width 0.5s;
    overflow: hidden;
}

.side-nav.hidden {
    width: 0;
    overflow: hidden;
}

.side-nav-title {
    width: 168PX;
    color: #e7f6ff;
    font-weight: bold;
    font-size: 20PX;
    padding: 20px;
    text-shadow: 0px 0px 20px #62c8f5;
}

.side-nav-sort {
    width: 168PX;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    color: #68abd2;
    font-size: 16PX;
    font-weight: bold;
    padding: 10px 20px;
    cursor: pointer;
}

.side-nav-item {
    width: 168PX;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    color: #68abd2;
    font-size: 16PX;
    padding: 10px 20px 10px 30px;
    cursor: pointer;
}

.side-nav-all.active,
.side-nav-all:hover,
.side-nav-item.active,
.side-nav-item:hover {
    color: #e2f5ff;
    background-color: #0c4586;
}

.side-nav-item.disable,
.side-nav-item.disable:hover {
    cursor: not-allowed;
    color: #366179;
    background-color: #082753;
}

.main-content {
    width: 100%;
    height: 100%;
    position: relative;
    transition: width 0.5s;
}

.short.main-content {
    width: calc(100% - 160px);
    padding-left: 30px;
    height: 100%;
    box-sizing: border-box;
    position: relative;
}

.side-nav-btn {
    position: absolute;
    width: 20px;
    height: 16px;
    left: 0;
    top: 50%;
    transform: translateY(-50%);
}

.side-nav-img {
    width: 30px;
    height: 24px;
    position: absolute;
    left: 4px;
    top: 50%;
    transform: translateY(-50%);
    cursor: pointer;
    z-index: 10;
    transition: transform 0.5s;
}

.side-nav-img.hidden {
    transform: translateY(-50%) rotate(180deg);
}

.sub-title-container {
    width: 100%;
    display: flex;
    justify-content: space-between;
    align-items: center;

    .sub-title-content {
        padding: 0 0 10px 22px;
        width: 90%;
        // font-size: 18px;
        font-size: 30px;
        // color: #b1e3ff;
        color: #fff;
        position: relative;
        text-shadow: 0px 0px 0.83333vw #4683fd;
        letter-spacing: 3PX;
    }

    .sub-title-content:after {
        content: '';
        position: absolute;
        left: -18px;
        top: -15px;
        width: 60px;
        height: 60px;
        background: url('~@/assets/img/bigScreen/air-title.png') no-repeat;
        background-size: cover;
    }

    .sub-back {
        width: 22PX;
        height: 22PX;
        padding-left: 15px;
        cursor: pointer;
    }
}

.sub-content-container {
    width: 100%;
    height: calc(100% - 30px);
    box-sizing: border-box;
}
</style>
